Merge branch 't/test_man'
[paraslash.git] / write.h
diff --git a/write.h b/write.h
index 56a9711a44af6fde00ef23f6f5d203e407daf4d0..0cfcafdade93f8334a9b8236656ba967def148ec 100644 (file)
--- a/write.h
+++ b/write.h
@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006-2012 Andre Noll <maan@systemlinux.org>
+ * Copyright (C) 2006-2014 Andre Noll <maan@systemlinux.org>
  *
  * Licensed under the GPL v2. For licencing details see COPYING.
  */
@@ -39,14 +39,14 @@ struct writer {
        /**
         * The command line parser of the writer.
         *
* It should check whether the command line options given by \a options
* are valid and return a pointer to the writer-specific configuration
* data determined by \a options. This function must either succeed or
* call exit(). Note that parse_config_or_die() might be called more
* than once with different values of \a options. \sa \ref
* free_config().
         */
-       void *(*parse_config_or_die)(const char *options);
+       void *(*parse_config_or_die)(int argc, char **argv);
        /**
         * Dellocate all configuration resources.
         *
@@ -65,19 +65,13 @@ struct writer {
         *
         * Called from the post_select function of the writer node's task.
         */
-       void (*post_select)(struct sched *s, struct task *t);
+       int (*post_select)(struct sched *s, struct task *t);
        /**
         * Close one instance of the writer.
         *
         * This function is assumed to succeed.
         */
        void (*close)(struct writer_node *);
-       /**
-        * Shutdown the writer.
-        *
-        * This is a optional function pointer used for cleaning up.
-        */
-       void (*shutdown)(struct writer_node *);
        /** The short and the log help text of this writer. */
        struct ggo_help help;
        /**
@@ -39,14 +39,14 @@ struct writer {
         * The command line parser of the writer.
         *
-        * It should check whether the command line options given by \a options
-        * are valid and return a pointer to the writer-specific configuration
-        * data determined by \a options. This function must either succeed or
-        * call exit(). Note that parse_config_or_die() might be called more
-        * than once with different values of \a options. \sa \ref
-        * free_config().
+        * It should check whether the command line options given by \a argv
+        * and \a argc are valid and return a pointer to the writer-specific
+        * configuration data determined by these options. This function must
+        * either succeed or call exit(). Note that parse_config_or_die() might
+        * be called more than once with different values of \a options. \sa
+        * \ref free_config().
         */